@@ -4,6 +4,7 @@ This module lists all externally useful classes and functions
 
 from ._version import __version__
 from .api import (
+    AsyncProcessRequest,
     BatchCollection,
     BatchRequest,
     BatchRequestStatus,
@@ -24,6 +25,7 @@ from .api import (
     WcsRequest,
     WebFeatureService,
     WmsRequest,
+    get_async_running_status,
     monitor_batch_analysis,
     monitor_batch_job,
     monitor_batch_statistical_analysis,
@@ -53,6 +55,7 @@ from .download import (
     SentinelHubSession,
     SentinelHubStatisticalDownloadClient,
 )
+from .evalscript import generate_evalscript, parse_data_collection_bands
 from .exceptions import AwsDownloadFailedException, DownloadFailedException
 from .geo_utils import (
     bbox_to_dimensions,
@@ -68,8 +71,7 @@ from .geo_utils import (
     wgs84_to_pixel,
     wgs84_to_utm,
 )
-from .geometry import BBox, BBoxCollection, Geometry
+from .geometry import BBox, Geometry
 from .geopedia import GeopediaFeatureIterator, GeopediaImageRequest, GeopediaSession, GeopediaWmsRequest
 from .io_utils import read_data, write_data
-from .os_utils import create_parent_folder, get_content_list, get_file_list, get_folder_list, make_folder, rename, size
 from .time_utils import filter_times, is_valid_time, parse_time, parse_time_interval, serialize_time
